@@ -1,6 +1,4 @@
 #
-# $Date: 2005/03/15 21:15:49 $
-#
 # Functions to check and get the arguments from URL
 #
 # ver 2.00+
@@ -348,7 +346,7 @@ sub check_host {
         Print::print_check_err("Missing host argument");
     }
     unless ($Args::args{'host'} =~ /^$::REG_HOST$/o) {
-        Print::print_check_err("Invalid host value: $Args::args{'host'}");
+        Print::print_check_err("Invalid host value");
     }
     return 0;
 }
@@ -555,7 +553,7 @@ sub get_mod {
 
 sub check_mnt {
     my $ftype = Args::get_ftype();
-    if (($ftype eq "dls") || ($ftype eq "swap") || ($ftype eq "raw")) {
+    if (($ftype eq "blkls") || ($ftype eq "swap") || ($ftype eq "raw")) {
         $Args::args{'mnt'}     = $ftype;
         $Args::enc_args{'mnt'} = $ftype;
     }
@@ -826,9 +824,9 @@ sub get_unitsize {
 
     my $vol   = Args::get_vol('vol');
     my $ftype = $Caseman::vol2ftype{$vol};
-    my $dcat_out;
+    my $blkcat_out;
 
-    if ($ftype eq 'dls') {
+    if ($ftype eq 'blkls') {
         if (exists $Caseman::mod2vol{$vol}) {
             my $orig    = $Caseman::mod2vol{$vol};
             my $img     = $Caseman::vol2path{$orig};
@@ -837,9 +835,9 @@ sub get_unitsize {
 
             local *OUT;
             Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $Caseman::vol2ftype{$orig} -s -o $offset -i $imgtype $img"
+"'$::TSKDIR/blkcat' -f $Caseman::vol2ftype{$orig} -s -o $offset -i $imgtype $img"
             );
-            $dcat_out = <OUT>;
+            $blkcat_out = <OUT>;
             close(OUT);
         }
 
@@ -864,19 +862,19 @@ sub get_unitsize {
 
         local *OUT;
         Exec::exec_pipe(*OUT,
-            "'$::TSKDIR/dcat' -f $ftype -s -o $offset -i $imgtype $img");
-        $dcat_out = <OUT>;
+            "'$::TSKDIR/blkcat' -f $ftype -s -o $offset -i $imgtype $img");
+        $blkcat_out = <OUT>;
         close(OUT);
     }
-    $dcat_out = "Error getting unit size"
-      if ((!defined $dcat_out) || ($dcat_out eq ""));
+    $blkcat_out = "Error getting unit size"
+      if ((!defined $blkcat_out) || ($blkcat_out eq ""));
 
-    if ($dcat_out =~ /(\d+): Size of Addressable Unit/) {
+    if ($blkcat_out =~ /(\d+): Size of Addressable Unit/) {
         return $1;
     }
     else {
-        Print::print_err("Error identifying block size (dcat -s output)<br>\n"
-              . "$dcat_out<br>\n");
+        Print::print_err("Error identifying block size (blkcat -s output)\n"
+              . "$blkcat_out\n");
     }
 }
 
@@ -913,7 +911,7 @@ sub check_vol {
     if ((!exists $Args::args{$vol}) || ($Args::args{$vol} !~ /^$::REG_VNAME$/))
     {
         Print::print_check_err(
-            "Invalid volume ($vol) argument (name and number only)");
+            "Invalid volume argument (name and number only)");
     }
     return 0;
 }
