@@ -1,6 +1,4 @@
 #
-# $Date: 2007/12/21 18:05:15 $
-#
 # Data / Content layer functions
 #
 # Brian Carrier [carrier@sleuthkit.org]
@@ -51,8 +49,8 @@ $Data::SORT_HEX = 1;
 $Data::SORT_STR = 2;
 
 # Types of block numbers
-$Data::ADDR_DD  = 0;
-$Data::ADDR_DLS = 1;
+$Data::ADDR_DD    = 0;
+$Data::ADDR_BLKLS = 1;
 
 sub main {
 
@@ -162,13 +160,13 @@ sub enter {
 
     print "<p><b>$Fs::addr_unit{$ftype} Size:</b>" . "&nbsp;$bs\n";
 
-    # dls images do not get to select this
-    # if (($ftype ne 'dls') && ($ftype ne 'swap') && ($ftype ne 'raw')) {
+    # blkls images do not get to select this
+    # if (($ftype ne 'blkls') && ($ftype ne 'swap') && ($ftype ne 'raw')) {
     if ($Fs::is_fs{$ftype} == 1) {
         print "<p><b>Address Type:</b><br>&nbsp;&nbsp;&nbsp;&nbsp;"
           . "<select name=\"btype\" size=1>\n"
           . "<option value=\"$Data::ADDR_DD\" selected>Regular (dd)</option>\n"
-          . "<option value=\"$Data::ADDR_DLS\">Unallocated (dls)</option>\n"
+          . "<option value=\"$Data::ADDR_BLKLS\">Unallocated (blkls)</option>\n"
           . "</select>\n";
     }
     else {
@@ -189,21 +187,21 @@ sub enter {
       . "width=113 height=20 alt=\"Allocation List\"></a><br>\n"
       if ($Fs::is_fs{$ftype} == 1);
 
-   #      unless (($ftype eq 'dls') || ($ftype eq 'swap') || ($ftype eq 'raw'));
+ #      unless (($ftype eq 'blkls') || ($ftype eq 'swap') || ($ftype eq 'raw'));
 
-    # If there is a dls image, then provide a button for it
-    if (($ftype ne 'dls') && (exists $Caseman::vol2dls{$vol})) {
+    # If there is a blkls image, then provide a button for it
+    if (($ftype ne 'blkls') && (exists $Caseman::vol2blkls{$vol})) {
         print "<form action=\"$::PROGNAME\" method=\"get\" target=\"_top\">\n"
           . "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_FRAME\">\n"
           . "<input type=\"hidden\" name=\"submod\" value=\"$::MOD_DATA\">\n"
-          . "<input type=\"hidden\" name=\"vol\" value=\"$Caseman::vol2dls{$vol}\">\n"
+          . "<input type=\"hidden\" name=\"vol\" value=\"$Caseman::vol2blkls{$vol}\">\n"
           . Args::make_hidden()
           . "<p><input type=\"image\" src=\"pict/srch_b_lun.jpg\" "
           . "alt=\"Load Unallocated Image\" border=\"0\">\n<br></form>\n";
     }
 
-    # If we are using a dls image, then give a button for the original
-    elsif (($ftype eq 'dls') && (exists $Caseman::mod2vol{$vol})) {
+    # If we are using a blkls image, then give a button for the original
+    elsif (($ftype eq 'blkls') && (exists $Caseman::mod2vol{$vol})) {
         print "<form action=\"$::PROGNAME\" method=\"get\" target=\"_top\">\n"
           . "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_FRAME\">\n"
           . "<input type=\"hidden\" name=\"submod\" value=\"$::MOD_DATA\">\n"
@@ -238,9 +236,9 @@ sub content_menu_frame {
     my $off = 0;
     $off = -1 if (exists $Args::args{'btype2'});
 
-    # Do we need to convert from dls value to dd value ?
+    # Do we need to convert from blkls value to dd value ?
     if (   (exists $Args::args{'btype'})
-        && ($Args::args{'btype'} == $Data::ADDR_DLS))
+        && ($Args::args{'btype'} == $Data::ADDR_BLKLS))
     {
 
         my $vol     = Args::get_vol('vol');
@@ -252,7 +250,7 @@ sub content_menu_frame {
 
         local *OUT;
         Exec::exec_pipe(*OUT,
-            "'$::TSKDIR/dcalc' -f $ftype -u $b -o $offset -i $imgtype $img");
+            "'$::TSKDIR/blkcalc' -f $ftype -u $b -o $offset -i $imgtype $img");
         $blk = Exec::read_pipe_line(*OUT);
         close(OUT);
 
@@ -316,19 +314,21 @@ sub print_ifind {
 
             # Make it red if it is deleted
             if (/^(\*)\s+\/*(.*)$/) {
-                Print::print_output(
-"<tt><font color=\"$::DEL_COLOR[0]\">$tmpr$2</font></tt> (deleted)<br>\n"
-                );
+                Print::print_output("<tt><font color=\"$::DEL_COLOR[0]\">"
+                      . Print::html_encode(${tmpr} . ${2})
+                      . "</font></tt> (deleted)<br>\n");
             }
 
             # If it starts with a '/' then it must be a file
             elsif (/^\/(.*)$/) {
-                Print::print_output("<tt>$tmpr$1</tt><br>\n");
+                Print::print_output("<tt>"
+                      . Print::html_encode(${tmpr} . ${1})
+                      . "</tt><br>\n");
             }
 
             # this must be an error
             else {
-                Print::print_output("$_<br>\n");
+                Print::print_output(Print::html_encode($_) . "<br>\n");
             }
         }
         close(OUT);
@@ -456,16 +456,16 @@ sub content_menu {
       . "&block=$block&len=$len\" target=\"_blank\">report</a>)</td>\n"
       . "</tr></table>\n";
 
-    # Special case for 'dls' b.c. we need to specify original data unit size
+    # Special case for 'blkls' b.c. we need to specify original data unit size
     local *OUT;
-    if ($ftype eq 'dls') {
+    if ($ftype eq 'blkls') {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype -u $bs  -o $offset -i $imgtype $img $block | '$::FILE_EXE' -z -b -"
+"'$::TSKDIR/blkcat' -f $ftype -u $bs  -o $offset -i $imgtype $img $block | '$::FILE_EXE' -z -b -"
         );
     }
     else {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype  -o $offset -i $imgtype $img $block | '$::FILE_EXE' -z -b -"
+"'$::TSKDIR/blkcat' -f $ftype  -o $offset -i $imgtype $img $block | '$::FILE_EXE' -z -b -"
         );
     }
     my $file_type = Exec::read_pipe_line(*OUT);
@@ -486,7 +486,8 @@ sub content_menu {
     if ($Fs::is_fs{$ftype} == 1) {
 
         Exec::exec_pipe(*OUT,
-            "'$::TSKDIR/dstat' -f $ftype  -o $offset -i $imgtype $img $block");
+            "'$::TSKDIR/blkstat' -f $ftype  -o $offset -i $imgtype $img $block"
+        );
 
         my $cnt = 0;
         while ($_ = Exec::read_pipe_line(*OUT)) {
@@ -521,13 +522,13 @@ sub content_menu {
     }
 
     # Option to view original if it exists
-    if (   ($ftype eq 'dls')
+    if (   ($ftype eq 'blkls')
         && (exists $Caseman::mod2vol{$vol}))
     {
         print "<a href=\"$::PROGNAME?mod=$::MOD_DATA&"
           . "view=$Data::CONT_MENU_FR&${Args::baseargs_novol}"
           . "&vol=$Caseman::mod2vol{$vol}&"
-          . "block=$block&sort=$sort&len=$len&btype=$Data::ADDR_DLS\" "
+          . "block=$block&sort=$sort&len=$len&btype=$Data::ADDR_BLKLS\" "
           . "target=\"_parent\">View Original</a><br>\n";
     }
 
@@ -569,7 +570,7 @@ sub content {
 
     my $usize_str = "";
     $usize_str = " -u $bs "
-      if ($ftype eq 'dls');
+      if ($ftype eq 'blkls');
 
     local *OUT;
     if ($sort == $Data::SORT_HEX) {
@@ -577,7 +578,7 @@ sub content {
         Print::log_host_inv(
             "$Caseman::vol2sname{$vol}: Displaying Hex $log_str");
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str -h -o $offset -i $imgtype $img $block $len"
+"'$::TSKDIR/blkcat' -f $ftype $usize_str -h -o $offset -i $imgtype $img $block $len"
         );
     }
     elsif ($sort == $Data::SORT_ASC) {
@@ -585,7 +586,7 @@ sub content {
         Print::log_host_inv(
             "$Caseman::vol2sname{$vol}: Displaying ASCII $log_str");
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str -a -o $offset -i $imgtype $img $block $len"
+"'$::TSKDIR/blkcat' -f $ftype $usize_str -a -o $offset -i $imgtype $img $block $len"
         );
     }
     elsif ($sort == $Data::SORT_STR) {
@@ -593,7 +594,7 @@ sub content {
         Print::log_host_inv(
             "$Caseman::vol2sname{$vol}: Displaying string $log_str");
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str -o $offset -i $imgtype $img $block $len | '$::TSKDIR/srch_strings' -a"
+"'$::TSKDIR/blkcat' -f $ftype $usize_str -o $offset -i $imgtype $img $block $len | '$::TSKDIR/srch_strings' -a"
         );
     }
     print $_ while ($_ = Exec::read_pipe_data(*OUT, 512));
@@ -624,7 +625,7 @@ sub report {
     my $bs = Args::get_unitsize();
 
     my $usize_str = "";
-    $usize_str = " -u $bs " if ($ftype eq 'dls');
+    $usize_str = " -u $bs " if ($ftype eq 'blkls');
 
     Print::print_text_header("$vol" . "-"
           . "$Fs::addr_unit{$ftype}"
@@ -668,7 +669,7 @@ sub report {
     }
     print "$Fs::addr_unit{$ftype} Size: $bs\n";
 
-    # if (($ftype ne 'dls') && ($ftype ne 'raw') && ($ftype ne 'swap')) {
+    # if (($ftype ne 'blkls') && ($ftype ne 'raw') && ($ftype ne 'swap')) {
     if ($Fs::is_fs{$ftype} == 1) {
 
         local *OUT;
@@ -693,10 +694,12 @@ sub report {
             while ($_ = Exec::read_pipe_line(*OUT)) {
                 chop;
                 if (/^(\*)\s+\/*(.*)$/) {
-                    Print::print_output("  $tmpr$2 (deleted)\n");
+                    Print::print_output(
+                        "  $tmpr$2 (deleted)\n");
                 }
                 elsif (/^\/(.*)$/) {
-                    Print::print_output("  $tmpr$1\n");
+                    Print::print_output(
+                        "  $tmpr$1\n");
                 }
                 else {
                     Print::print_output("  $_\n");
@@ -707,10 +710,10 @@ sub report {
         else {
             print "Not allocated to any meta data structures\n";
         }
-    }    # not dls
+    }    # not blkls
 
     Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str  -o $offset -i $imgtype $img $block $len | '$::MD5_EXE'"
+"'$::TSKDIR/blkcat' -f $ftype $usize_str  -o $offset -i $imgtype $img $block $len | '$::MD5_EXE'"
     );
     my $md5 = Exec::read_pipe_line(*OUT);
     close(OUT);
@@ -723,17 +726,17 @@ sub report {
 
     if ($sort == $Data::SORT_HEX) {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str -h  -o $offset -i $imgtype $img $block $len | '$::MD5_EXE'"
+"'$::TSKDIR/blkcat' -f $ftype $usize_str -h  -o $offset -i $imgtype $img $block $len | '$::MD5_EXE'"
         );
     }
     elsif ($sort == $Data::SORT_ASC) {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str -a  -o $offset -i $imgtype $img $block $len | '$::MD5_EXE'"
+"'$::TSKDIR/blkcat' -f $ftype $usize_str -a  -o $offset -i $imgtype $img $block $len | '$::MD5_EXE'"
         );
     }
     elsif ($sort == $Data::SORT_STR) {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str  -o $offset -i $imgtype $img $block $len | '$::TSKDIR/srch_strings' -a | '$::MD5_EXE'"
+"'$::TSKDIR/blkcat' -f $ftype $usize_str  -o $offset -i $imgtype $img $block $len | '$::TSKDIR/srch_strings' -a | '$::MD5_EXE'"
         );
     }
 
@@ -767,20 +770,21 @@ sub report {
 
     if ($sort == $Data::SORT_HEX) {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str -h  -o $offset -i $imgtype $img $block $len"
+"'$::TSKDIR/blkcat' -f $ftype $usize_str -h  -o $offset -i $imgtype $img $block $len"
         );
     }
     elsif ($sort == $Data::SORT_ASC) {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str -a  -o $offset -i $imgtype $img $block $len"
+"'$::TSKDIR/blkcat' -f $ftype $usize_str -a  -o $offset -i $imgtype $img $block $len"
         );
     }
     elsif ($sort == $Data::SORT_STR) {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str  -o $offset -i $imgtype $img $block $len | '$::TSKDIR/srch_strings' -a"
+"'$::TSKDIR/blkcat' -f $ftype $usize_str  -o $offset -i $imgtype $img $block $len | '$::TSKDIR/srch_strings' -a"
         );
     }
-    Print::print_output($_) while ($_ = Exec::read_pipe_data(*OUT, 512));
+    Print::print_output($_)
+      while ($_ = Exec::read_pipe_data(*OUT, 512));
     close(OUT);
 
     print "\n"
@@ -800,7 +804,7 @@ sub report {
 sub list {
     Print::print_html_header("Block Allocation List");
 
-    my $DLS_GAP = 500;
+    my $BLKLS_GAP = 500;
 
     my $vol     = Args::get_vol('vol');
     my $ftype   = $Caseman::vol2ftype{$vol};
@@ -810,7 +814,7 @@ sub list {
 
     my $min = 0;
     $min = Args::get_min() if (exists $Args::args{'min'});
-    my $max = $min + $DLS_GAP - 1;
+    my $max = $min + $BLKLS_GAP - 1;
 
     # set fmin to the minimum for the file system
     my $fmin = $min;
@@ -822,14 +826,14 @@ sub list {
 
     my $tmp;
 
-    if ($min - $DLS_GAP >= 0) {
-        $tmp = $min - $DLS_GAP;
+    if ($min - $BLKLS_GAP >= 0) {
+        $tmp = $min - $BLKLS_GAP;
         print "<a href=\"$::PROGNAME?mod=$::MOD_DATA&view=$Data::LIST&"
           . "$Args::baseargs&min=$tmp\">"
           . "<img src=\"pict/but_prev.jpg\" alt=\"previous\" "
           . "width=\"89\" height=20 border=\"0\"></a> ";
     }
-    $tmp = $min + $DLS_GAP;
+    $tmp = $min + $BLKLS_GAP;
     print " <a href=\"$::PROGNAME?mod=$::MOD_DATA&view=$Data::LIST&"
       . "$Args::baseargs&min=$tmp\">"
       . "<img src=\"pict/but_next.jpg\" alt=\"next\" "
@@ -838,7 +842,7 @@ sub list {
 
     local *OUT;
     Exec::exec_pipe(*OUT,
-        "'$::TSKDIR/dls' -elb -f $ftype  -o $offset -i $imgtype $img $fmin-$max"
+"'$::TSKDIR/blkls' -el -f $ftype  -o $offset -i $imgtype $img $fmin-$max"
     );
     while ($_ = Exec::read_pipe_line(*OUT)) {
         if (/^(\d+)\|([af])/) {
@@ -856,14 +860,14 @@ sub list {
     close(OUT);
 
     print "<center>\n";
-    if ($min - $DLS_GAP >= 0) {
-        $tmp = $min - $DLS_GAP;
+    if ($min - $BLKLS_GAP >= 0) {
+        $tmp = $min - $BLKLS_GAP;
         print "<a href=\"$::PROGNAME?mod=$::MOD_DATA&view=$Data::LIST&"
           . "$Args::baseargs&min=$tmp\">"
           . "<img src=\"pict/but_prev.jpg\" alt=\"previous\" "
           . "width=\"89\" height=20 border=\"0\"></a> ";
     }
-    $tmp = $min + $DLS_GAP;
+    $tmp = $min + $BLKLS_GAP;
     print " <a href=\"$::PROGNAME?mod=$::MOD_DATA&view=$Data::LIST&"
       . "$Args::baseargs&min=$tmp\">"
       . "<img src=\"pict/but_next.jpg\" alt=\"next\" "
@@ -892,14 +896,14 @@ sub export {
     );
 
     local *OUT;
-    if ($ftype eq 'dls') {
+    if ($ftype eq 'blkls') {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype -u $bs  -o $offset -i $imgtype $img $block $len"
+"'$::TSKDIR/blkcat' -f $ftype -u $bs  -o $offset -i $imgtype $img $block $len"
         );
     }
     else {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype  -o $offset -i $imgtype $img $block $len"
+"'$::TSKDIR/blkcat' -f $ftype  -o $offset -i $imgtype $img $block $len"
         );
     }
     print "$_" while ($_ = Exec::read_pipe_data(*OUT, 512));
