@@ -1,6 +1,4 @@
 #
-# $Date: 2008/01/30 03:28:09 $
-#
 # Hash database and calculation functions
 #
 # Brian Carrier [carrier@sleuthkit.org]
@@ -515,7 +513,7 @@ sub img_list {
     Print::print_html_header("Image Integrity Menu");
 
     my %md5s;
-    my @dls;
+    my @blkls;
     my @str;
     my @img;
     my @body;
@@ -546,8 +544,8 @@ sub img_list {
         if ($Caseman::vol2cat{$k} eq "image") {
             push @img, $k;
         }
-        elsif ($Caseman::vol2ftype{$k} eq "dls") {
-            push @dls, $k;
+        elsif ($Caseman::vol2ftype{$k} eq "blkls") {
+            push @blkls, $k;
         }
         elsif ($Caseman::vol2ftype{$k} eq "strings") {
             push @str, $k;
@@ -571,17 +569,17 @@ sub img_list {
         int_menu_print(\%md5s, \@sort);
     }
 
-    # Unallocated (dls) images
-    if (scalar @dls > 0) {
+    # Unallocated (blkls) images
+    if (scalar @blkls > 0) {
         print "<tr><th colspan=3>&nbsp;</th></tr>\n"
           . "<tr><th colspan=3>"
           . "<img src=\"pict/int_h_unalloc.jpg\" alt=\"Unallocated Data Files\">"
           . "</th></tr>\n";
-        my @sort = sort { $a cmp $b } @dls;
+        my @sort = sort { $a cmp $b } @blkls;
         int_menu_print(\%md5s, \@sort);
     }
 
-    # Strings files (of dls or fs images)
+    # Strings files (of blkls or fs images)
     if (scalar @str > 0) {
         print "<tr><th colspan=3>&nbsp;</th></tr>\n"
           . "<tr><th colspan=3>"
@@ -801,8 +799,8 @@ sub calc_md5_split {
     alarm(5);
     local *OUT;
 
-    # We use the dls method so that we can handle split images
-    Exec::exec_pipe(*OUT, "'$::TSKDIR/dls' -f raw -e $img | '$::MD5_EXE'");
+    # We use the blkls method so that we can handle split images
+    Exec::exec_pipe(*OUT, "'$::TSKDIR/blkls' -f raw -e $img | '$::MD5_EXE'");
 
     alarm(0);
     $SIG{ALRM} = 'DEFAULT';
