@@ -413,7 +413,7 @@ sub stats {
     if (exists($Args::args{'force'})) {
         my $f = Args::get_force();
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/istat' -f $ftype $tz -s $Caseman::ts -b $f -o $offset -i $imgtype $img $meta"
+"'$::TSKDIR/istat' -f $ftype $tz -s $Caseman::ts -B $f -o $offset -i $imgtype $img $meta"
         );
     }
     else {
@@ -460,7 +460,8 @@ sub stats {
                 print "$_<br>\n";
             }
             $mode = 1 if (/^Direct Blocks|^Sectors/);
-            $mode = 1 if (/^Attributes/);
+            $mode = 1 if (/^Attributes:/);  # HFS gets messed up without ":"
+            $mode = 1 if (/^Data Fork Blocks:/); 
 
             if ((/^size: (\d+)/) && ($1 == 0)) {
                 $force = 1;
