@@ -1,8 +1,6 @@
 #
 # Timeline functions
 #
-# $Date: 2005/10/13 17:02:34 $
-#
 # Brian Carrier [carrier@sleuthkit.org]
 # Copyright (c) 2001-2005 by Brian Carrier.  All rights reserved
 #
@@ -297,8 +295,7 @@ sub body_enter {
       . "</td><td>Allocated Files</td>"
       . "<td><input type=\"checkbox\" name=\"unal_file\" value=\"1\" CHECKED>"
       . "</td><td>Unallocated Files</td>"
-      . "<td><input type=\"checkbox\" name=\"unal_meta\" value=\"1\" CHECKED>"
-      . "</td><td>Unallocated Meta Data Structures</td></tr></table>\n"
+      . "</tr></table>\n"
       . "<p>3.   Enter name of output file (<tt>body</tt>):<br>"
       . "<tt>$::DATADIR/</tt>"
       . "<input type=\"text\" name=\"fname\" value=\"body\">\n"
@@ -346,10 +343,6 @@ sub body_run {
             "<input type=\"hidden\" name=\"unal_file\" "
           . "value=\"$Args::args{'unal_file'}\">\n"
           if (exists $Args::args{'unal_file'});
-        $hidden .=
-            "<input type=\"hidden\" name=\"unal_meta\" "
-          . "value=\"$Args::args{'unal_meta'}\">\n"
-          if (exists $Args::args{'unal_meta'});
         $hidden .=
             "<input type=\"hidden\" name=\"md5\" "
           . "value=\"$Args::args{'md5'}\">\n"
@@ -399,14 +392,7 @@ sub body_run {
         $log_type .= "Unallocated Files";
     }
 
-    my $unal_meta = 0;
-    if (exists $Args::args{'unal_meta'}) {
-        $unal_meta = $Args::args{'unal_meta'};
-        $log_type .= ", " if ($log_type ne "");
-        $log_type .= "Unallocated Meta Data Structures";
-    }
-
-    if (($unal_meta == 0) && ($unal_file == 0) && ($al_file == 0)) {
+    if (($unal_file == 0) && ($al_file == 0)) {
         print
           "No data types were selected.  You must select at least one.<br>\n";
         return 1;
@@ -457,27 +443,6 @@ sub body_run {
                 print "$_<br>\n" while ($_ = Exec::read_pipe_line(*OUT));
                 close(OUT);
             }
-
-            if ($unal_meta) {
-                print "Running <tt>ils -m</tt> on <tt>$i</tt><br>\n";
-                my $tz_back = "";
-                if ($Caseman::tz ne "") {
-                    $tz_back = $ENV{TZ} if (exists $ENV{TZ});
-
-                    $ENV{TZ} = $Caseman::tz;
-                    POSIX::tzset();
-                }
-                Exec::exec_pipe(*OUT,
-"'$::TSKDIR/ils' -s $Caseman::ts -m -f $ftype -o $offset -i $imgtype $img >> '$fname'"
-                );
-                print "$_<br>\n" while ($_ = Exec::read_pipe_line(*OUT));
-                close(OUT);
-
-                if ($Caseman::tz ne "") {
-                    $ENV{TZ} = $tz_back;
-                    POSIX::tzset();
-                }
-            }
         }
     }
 
@@ -825,26 +790,40 @@ sub tl_run {
         if (exists $Args::args{'st_mon'}) {
             Args::check_st_mon();
             $mon = Args::get_st_mon();
+            if (($mon < 1) || ($mon > 12)) {
+                print("Invalid starting month\n");
+                return 1;
+            }
+            if ($mon < 10) {
+                $mon = "0" . $mon;
+            }
         }
         if (exists $Args::args{'st_year'}) {
             Args::check_st_year();
             $year = Args::get_st_year();
+            if (($year < 1970) || ($year > 2020)) {
+                print("Invalid starting year\n");
+                return 1;
+            }
         }
         if (   (exists $Args::args{'st_day'})
             && ($Args::args{'st_day'} =~ /^(\d\d?)$/))
         {
             $day = $1;
             if (($day < 1) || ($day > 31)) {
-                print("Invalid start day\n");
+                print("Invalid starting day\n");
                 return 1;
             }
+            if ($day < 10) {
+                $day = "0" . $day;
+            }
         }
         else {
             print("Invalid start day\n");
             return 1;
         }
 
-        $date = "$mon/$day/$year";
+        $date = "$year-$mon-$day";
     }
 
     unless ((exists $Args::args{'end_none'}) && ($Args::args{'end_none'} == 1))
@@ -863,6 +842,9 @@ sub tl_run {
                 print("Invalid end month\n");
                 return 1;
             }
+            if ($mon < 10) {
+                $mon = "0" . $mon;
+            }
         }
         else {
             print("Invalid end month\n");
@@ -890,13 +872,16 @@ sub tl_run {
                 print("Invalid end day\n");
                 return 1;
             }
+            if ($day < 10) {
+                $day = "0" . $day;
+            }
         }
         else {
             print("Invalid end day\n");
             return 1;
         }
 
-        $date .= "-$mon/$day/$year";
+        $date .= "..$year-$mon-$day";
     }
 
     # temp strings for the password and group files
@@ -1351,7 +1336,7 @@ sub view {
     my $row  = 0;
     while (<TL>) {
         if (
-/^(?:(\w\w\w\s+)?(\w\w\w\s+\d\d\s+\d\d\d\d)\s+(\d\d:\d\d:\d\d))?\s+(\d+)\s+([mac\.]+)\s+([-\/\?\w]+)\s+([\d\w\/]+)\s+([\d\w\/]+)\s+($::REG_META)\s+(.*)$/o
+/^(?:(\w\w\w\s+)?(\w\w\w\s+\d\d\s+\d\d\d\d)\s+(\d\d:\d\d:\d\d))?\s+(\d+)\s+([macb\.]+)\s+([-\/\?\w]+)\s+([\d\w\/]+)\s+([\d\w\/]+)\s+($::REG_META)\s+(.*)$/o
           )
         {
 
@@ -1406,13 +1391,17 @@ sub view {
 
                 print "<td>$day&nbsp;$date&nbsp;$time</td>"
                   . "<td>$sz</td><td>$mac</td><td>$p</td>"
-                  . "<td>$u</td><td>$g</td><td>$i</td><td>$f</td></tr>\n";
+                  . "<td>$u</td><td>$g</td><td>$i</td><td>"
+                  . Print::html_encode($f)
+                  . "</td></tr>\n";
 
                 $row++;
             }
         }
         else {
-            print "Error parsing timeline: $_<br>\n";
+            print "Error parsing timeline: "
+              . Print::html_encode($_)
+              . "<br>\n";
         }
     }
     close(TL);
